.. blosc2 documentation master file, created by
   sphinx-quickstart on Mon Apr 19 12:06:38 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :hidden:

   API Reference <reference/index>
   Release Notes <release_notes/index>
